==> apache-hyracks-0.3.2-source-release.zip: apache-hyracks-0.3.2/hyracks/hyracks-api/src/main/java/org/apache/hyracks/api/client/ClusterControllerInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.hyracks.api.client;

import java.io.Serializable;

public class ClusterControllerInfo implements Serializable {
    private static final long serialVersionUID = 1L;

    private final String clientNetAddress;

    private final int clientNetPort;

    private final int webPort;

    public ClusterControllerInfo(String clientNetAddress, int clientNetPort, int webPort) {
        this.clientNetAddress = clientNetAddress;
        this.clientNetPort = clientNetPort;
        this.webPort = webPort;
    }

    public int getWebPort() {
        return webPort;
    }

    public String getClientNetAddress() {
        return clientNetAddress;
    }

    public int getClientNetPort() {
        return clientNetPort;
    }
}

==> apache-hyracks-0.3.4-source-release.zip: apache-hyracks-0.3.4/hyracks/hyracks-api/src/main/java/org/apache/hyracks/api/client/ClusterControllerInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.hyracks.api.client;

import org.apache.hyracks.api.control.CcId;

import java.io.Serializable;

public class ClusterControllerInfo implements Serializable {
    private static final long serialVersionUID = 1L;

    private final CcId ccId;

    private final String clientNetAddress;

    private final int clientNetPort;

    private final int webPort;

    public ClusterControllerInfo(CcId ccId, String clientNetAddress, int clientNetPort, int webPort) {
        this.ccId = ccId;
        this.clientNetAddress = clientNetAddress;
        this.clientNetPort = clientNetPort;
        this.webPort = webPort;
    }

    public CcId getCcId() {
        return ccId;
    }

    public int getWebPort() {
        return webPort;
    }

    public String getClientNetAddress() {
        return clientNetAddress;
    }

    public int getClientNetPort() {
        return clientNetPort;
    }
}
